@@ -78,7 +78,9 @@ enum HelpVariableName {
     CopyExtension,
     MBoxMetaDataExtension,
     SubAddressExtension,
-    ERejectAction
+    ERejectAction,
+    ImapFlagsExtension,
+    EditHeaderExtension
 };
 KSieveUi::SieveEditorUtil::HelpVariableName strToVariableName(const QString &str);
 
